@@ -356,11 +356,10 @@ static int do_recv(struct abstract_read **r, UINT32 length, UINT8 *buffer, abstr
 
 	for (;;) {
 		int res = recvfrom(closure->fd, buffer, length, 0, (struct sockaddr *) addr, (socklen_t *) addrlen);
-		if (!res) {
 
-			debug("Read EOF on fd %i.\n", closure->fd);
-
-			return A_EOF;
+		if (res == 0) {
+			/* on SOCK_DGRAM protocols 0 returned bytes doesn't mean anything */
+			return 0;
 		}
 		if (res > 0)
 			return res;
